==> apache-camel-3.0.0-src.zip: apache-camel-3.0.0/components/camel-printer/src/main/java/org/apache/camel/component/printer/PrinterComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.printer;

import java.net.URI;
import java.util.Map;

import org.apache.camel.Endpoint;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;

@Component("lpr")
public class PrinterComponent extends DefaultComponent {

    public PrinterComponent() {

    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        PrinterConfiguration config = new PrinterConfiguration();
        config.parseURI(new URI(uri));

        PrinterEndpoint printerEndpoint = new PrinterEndpoint(uri, this, config);
        setProperties(printerEndpoint.getConfig(), parameters);
        return new PrinterEndpoint(uri, this, config);
    }
}

==> apache-camel-4.12.0-src.zip: apache-camel-4.12.0/components/camel-printer/src/main/java/org/apache/camel/component/printer/PrinterComponent.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.printer;

import java.net.URI;
import java.util.Map;

import org.apache.camel.Endpoint;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;

@Component("lpr")
public class PrinterComponent extends DefaultComponent {

    public PrinterComponent() {

    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        PrinterConfiguration config = new PrinterConfiguration();
        config.parseURI(new URI(uri));

        PrinterEndpoint printerEndpoint = new PrinterEndpoint(uri, this, config);
        setProperties(printerEndpoint, parameters);
        return printerEndpoint;
    }
}
